# Eve IDS
EVE_CATEGORY_ID_STARBASE = 23
EVE_CATEGORY_ID_ORBITAL = 46
EVE_CATEGORY_ID_STRUCTURE = 65

EVE_GROUP_ID_CONTROL_TOWER = 365
EVE_GROUP_ID_FUEL_BLOCK = 1136
EVE_GROUP_ID_REFINERY = 1406

EVE_TYPE_ID_POCO = 2233
EVE_TYPE_ID_TCU = 32226
EVE_TYPE_ID_IHUB = 32458
EVE_TYPE_ID_STRONTIUM = 16275
