{% load i18n %}
{% load bootstrap %}

<div role="tabpanel" class="tab-pane" id="pocos">
    <div class="table-responsive">
        <!-- pocos list -->
        <table id="tab_pocos" style="width: 100%" class="table table-striped table-compact">
            <thead>
                <tr>
                    <th></th>
                    <th>{% translate "Region" %}</th>
                    <th>{% translate "Solar System" %}</th>
                    <th>{% translate "Planet" %}</th>
                    <th></th>
                    <th>{% translate "Planet Type" %}</th>
                </tr>
            </thead>
        </table>
    </div>
</div>
